**Example 1: 删除媒体库**

删除媒体库

Input: 

```
tccli smh DeleteLibrary --cli-unfold-argument  \
    --LibraryId smh0q8nrvsg7t6y6
```

Output: 
```
{
    "Response": {
        "RequestId": "ea829232-caa0-4dfe-9bbb-2f428cfae08c"
    }
}
```

